==> vgm.4.4.tar.gz: vgm.4.4/test/src/TstVGeometry.cc <==
// $Id: TstVGeometry.cc 665 2010-02-23 14:56:32Z ihrivnac $

// -----------------------------------------------------------------------
// The test program of the Virtual Geometry Model
// Copyright (C) 2007, Ivana Hrivnacova               
// All rights reserved. 
//           
// For the licensing terms see vgm/LICENSE.
// Contact: ivana@ipno.in2p3.fr
// -----------------------------------------------------------------------

//
// Class TstVGeometry
// --------------------------
// The interface to test geometry builders
//
// Author: Ivana Hrivnacova; IPN Orsay

#include "TstVGeometry.hh"

#include <iostream>
#include <cstdlib>

//_____________________________________________________________________________
TstVGeometry::TstVGeometry()
{
//
}  

//_____________________________________________________________________________
TstVGeometry::~TstVGeometry()
{
//
}

//_____________________________________________________________________________
void* TstVGeometry::TestAssemblies()
{
//
  std::cerr << "TstVGeometry::TestAssemblies is not implemented." 
            << std::endl;
  exit(1);
}  
  
//_____________________________________________________________________________
void* TstVGeometry::TestAssemblies2()
{
//
  std::cerr << "TstVGeometry::TestAssemblies2 is not implemented." 
            << std::endl;
  exit(1);
}  
  
//_____________________________________________________________________________
void* TstVGeometry::TestBooleanSolids4()
{
//
  std::cerr << "TstVGeometry::TestBooleanSolids4 is not implemented." 
            << std::endl;
  exit(1);
}  
  
    

//_____________________________________________________________________________
void* TstVGeometry::TestBooleanSolids5()
{
//
  std::cerr << "TstVGeometry::TestBooleanSolids5 is not implemented." 
            << std::endl;
  exit(1);
}  

//_____________________________________________________________________________
void* TstVGeometry::TestBooleanSolids6()
{
//
  std::cerr << "TstVGeometry::TestBooleanSolids6 is not implemented." 
            << std::endl;
  exit(1);
}  

//_____________________________________________________________________________
void* TstVGeometry::TestBooleanSolids7()
{
//
  std::cerr << "TstVGeometry::TestBooleanSolids7 is not implemented." 
            << std::endl;
  exit(1);
}  

//_____________________________________________________________________________
void* TstVGeometry::TestDisplacedSolids1()
{
//
  std::cerr << "TstVGeometry::TestDisplacedSolids is not implemented." 
            << std::endl;
  exit(1);
}  

//_____________________________________________________________________________
void* TstVGeometry::TestDisplacedSolids2()
{
//
  std::cerr << "TstVGeometry::TestDisplacedSolids is not implemented." 
            << std::endl;
  exit(1);
}  

//_____________________________________________________________________________
void* TstVGeometry::TestSpecial()
{
//
  std::cerr << "TstVGeometry::TestSpecial is not implemented." 
            << std::endl;
  exit(1);
}

==> vgm-5.0.tar.gz: vgm-5-0/test/src/TstVGeometry.cc <==
// $Id$

// -----------------------------------------------------------------------
// The test program of the Virtual Geometry Model
// Copyright (C) 2007, Ivana Hrivnacova
// All rights reserved.
//
// For the licensing terms see vgm/LICENSE.
// Contact: ivana@ipno.in2p3.fr
// -----------------------------------------------------------------------

//
// Class TstVGeometry
// --------------------------
// The interface to test geometry builders
//
// Author: Ivana Hrivnacova; IPN Orsay

#include "TstVGeometry.hh"

#include <cstdlib>
#include <iostream>

//_____________________________________________________________________________
TstVGeometry::TstVGeometry()
{
  //
}

//_____________________________________________________________________________
TstVGeometry::~TstVGeometry()
{
  //
}

//_____________________________________________________________________________
void* TstVGeometry::TestAssemblies()
{
  //
  std::cerr << "TstVGeometry::TestAssemblies is not implemented." << std::endl;
  exit(1);
}

//_____________________________________________________________________________
void* TstVGeometry::TestAssemblies2()
{
  //
  std::cerr << "TstVGeometry::TestAssemblies2 is not implemented." << std::endl;
  exit(1);
}

//_____________________________________________________________________________
void* TstVGeometry::TestBooleanSolids4()
{
  //
  std::cerr << "TstVGeometry::TestBooleanSolids4 is not implemented."
            << std::endl;
  exit(1);
}

//_____________________________________________________________________________
void* TstVGeometry::TestBooleanSolids5()
{
  //
  std::cerr << "TstVGeometry::TestBooleanSolids5 is not implemented."
            << std::endl;
  exit(1);
}

//_____________________________________________________________________________
void* TstVGeometry::TestBooleanSolids6()
{
  //
  std::cerr << "TstVGeometry::TestBooleanSolids6 is not implemented."
            << std::endl;
  exit(1);
}

//_____________________________________________________________________________
void* TstVGeometry::TestBooleanSolids7()
{
  //
  std::cerr << "TstVGeometry::TestBooleanSolids7 is not implemented."
            << std::endl;
  exit(1);
}

//_____________________________________________________________________________
void* TstVGeometry::TestDisplacedSolids1()
{
  //
  std::cerr << "TstVGeometry::TestDisplacedSolids is not implemented."
            << std::endl;
  exit(1);
}

//_____________________________________________________________________________
void* TstVGeometry::TestDisplacedSolids2()
{
  //
  std::cerr << "TstVGeometry::TestDisplacedSolids is not implemented."
            << std::endl;
  exit(1);
}

//_____________________________________________________________________________
void* TstVGeometry::TestSpecial()
{
  //
  std::cerr << "TstVGeometry::TestSpecial is not implemented." << std::endl;
  exit(1);
}
